@@ -11,6 +11,7 @@
 
 namespace Symfony\Polyfill\Tests\Iconv;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Polyfill\Iconv\Iconv as p;
 
 /**
@@ -18,7 +19,7 @@ use Symfony\Polyfill\Iconv\Iconv as p;
  *
  * @covers Symfony\Polyfill\Iconv\Iconv::<!public>
  */
-class IconvTest extends \PHPUnit_Framework_TestCase
+class IconvTest extends TestCase
 {
     /**
      * @covers Symfony\Polyfill\Iconv\Iconv::iconv
@@ -33,9 +34,10 @@ class IconvTest extends \PHPUnit_Framework_TestCase
         }
 
         $this->assertSame(utf8_decode('déjà'), iconv('CP1252', 'ISO-8859-1', utf8_decode('déjà')));
-        $this->assertSame('deja noeud', p::iconv('UTF-8', 'US-ASCII//TRANSLIT', 'déjà nœud'));
+        $this->assertSame('deja noeud', p::iconv('UTF-8//ignore//IGNORE', 'US-ASCII//TRANSLIT//IGNORE//translit', 'déjà nœud'));
 
         $this->assertSame('4', iconv('UTF-8', 'UTF-8', 4));
+        $this->assertSame('aa', p::iconv('UTF-8', "ASCII//TRANSLIT//IGNORE", "a\xC2\x96a"));
     }
 
     /**
@@ -60,7 +62,7 @@ class IconvTest extends \PHPUnit_Framework_TestCase
     {
         $this->assertSame(1, iconv_strpos('11--', '1-', 0, 'UTF-8'));
         $this->assertSame(2, iconv_strpos('-11--', '1-', 0, 'UTF-8'));
-        $this->assertSame(false, iconv_strrpos('한국어', '', 'UTF-8'));
+        $this->assertFalse(iconv_strrpos('한국어', '', 'UTF-8'));
         $this->assertSame(1, iconv_strrpos('한국어', '국', 'UTF-8'));
     }
 
@@ -110,7 +112,7 @@ class IconvTest extends \PHPUnit_Framework_TestCase
     public function testIconvMimeDecodeIllegal()
     {
         iconv_mime_decode('Legal encoded-word: =?utf-8?Q?*?= .');
-        $this->setExpectedException('PHPUnit_Framework_Error_Notice', 'Detected an illegal character in input string');
+        $this->setExpectedException('PHPUnit\Framework\Error\Notice', 'Detected an illegal character in input string');
         iconv_mime_decode('Illegal encoded-word: =?utf-8?Q?'.chr(0xA1).'?= .');
     }
 
@@ -163,4 +165,17 @@ HEADERS;
 
         $this->assertFalse(@iconv_set_encoding('foo', 'UTF-8'));
     }
+
+    public function setExpectedException($exception, $message = '', $code = null)
+    {
+        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
+            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
+        }
+        if (method_exists($this, 'expectException')) {
+            $this->expectException($exception);
+            $this->expectExceptionMessage($message);
+        } else {
+            parent::setExpectedException($exception, $message, $code);
+        }
+    }
 }
