@@ -11,6 +11,7 @@
 
 namespace Symfony\Polyfill\Tests\Intl\Grapheme;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Polyfill\Intl\Grapheme\Grapheme as p;
 
 /**
@@ -18,7 +19,7 @@ use Symfony\Polyfill\Intl\Grapheme\Grapheme as p;
  *
  * @covers Symfony\Polyfill\Intl\Grapheme\Grapheme::<!public>
  */
-class GraphemeTest extends \PHPUnit_Framework_TestCase
+class GraphemeTest extends TestCase
 {
     /**
      * @covers Symfony\Polyfill\Intl\Grapheme\Grapheme::grapheme_extract
@@ -26,7 +27,7 @@ class GraphemeTest extends \PHPUnit_Framework_TestCase
     public function testGraphemeExtractArrayError()
     {
         grapheme_extract('', 0);
-        $this->setExpectedException('PHPUnit_Framework_Error_Warning', 'expects parameter 1 to be string, array given');
+        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 1 to be string, array given');
         grapheme_extract(array(), 0);
     }
 
@@ -80,15 +81,15 @@ class GraphemeTest extends \PHPUnit_Framework_TestCase
             // See http://bugs.php.net/62759 and 55562
             $this->assertSame('jà', grapheme_substr($c, -2,  3));
             $this->assertSame('', grapheme_substr($c, -1,  0));
-            $this->assertSame(false, grapheme_substr($c,  1, -4));
+            $this->assertFalse(grapheme_substr($c,  1, -4));
         }
 
         $this->assertSame('jà', grapheme_substr($c,  2));
         $this->assertSame('jà', grapheme_substr($c, -2));
         $this->assertSame('j', grapheme_substr($c, -2, -1));
         $this->assertSame('', grapheme_substr($c, -2, -2));
-        $this->assertSame(false, grapheme_substr($c,  5,  0));
-        $this->assertSame(false, grapheme_substr($c, -5,  0));
+        $this->assertFalse(grapheme_substr($c,  5,  0));
+        $this->assertFalse(grapheme_substr($c, -5,  0));
     }
 
     /**
@@ -100,9 +101,9 @@ class GraphemeTest extends \PHPUnit_Framework_TestCase
      */
     public function testGraphemeStrpos()
     {
-        $this->assertSame(false, grapheme_strpos('abc', ''));
-        $this->assertSame(false, grapheme_strpos('abc', 'd'));
-        $this->assertSame(false, grapheme_strpos('abc', 'a', 3));
+        $this->assertFalse(grapheme_strpos('abc', ''));
+        $this->assertFalse(grapheme_strpos('abc', 'd'));
+        $this->assertFalse(grapheme_strpos('abc', 'a', 3));
         if (PHP_VERSION_ID < 50535 || (50600 <= PHP_VERSION_ID && PHP_VERSION_ID < 50621) || (70000 <= PHP_VERSION_ID && PHP_VERSION_ID < 70006)) {
             $this->assertSame(0, grapheme_strpos('abc', 'a', -1));
         } else {
@@ -110,7 +111,7 @@ class GraphemeTest extends \PHPUnit_Framework_TestCase
         }
         $this->assertSame(1, grapheme_strpos('한국어', '국'));
         $this->assertSame(3, grapheme_stripos('DÉJÀ', 'à'));
-        $this->assertSame(false, grapheme_strrpos('한국어', ''));
+        $this->assertFalse(grapheme_strrpos('한국어', ''));
         $this->assertSame(1, grapheme_strrpos('한국어', '국'));
         $this->assertSame(3, grapheme_strripos('DÉJÀ', 'à'));
     }
@@ -134,4 +135,17 @@ class GraphemeTest extends \PHPUnit_Framework_TestCase
         $this->assertSame(16, grapheme_stripos('der Straße nach Paris', 'Paris'));
         $this->assertSame('Paris', grapheme_stristr('der Straße nach Paris', 'Paris'));
     }
+
+    public function setExpectedException($exception, $message = '', $code = null)
+    {
+        if (!class_exists('PHPUnit\Framework\Error\Notice')) {
+            $exception = str_replace('PHPUnit\\Framework\\Error\\', 'PHPUnit_Framework_Error_', $exception);
+        }
+        if (method_exists($this, 'expectException')) {
+            $this->expectException($exception);
+            $this->expectExceptionMessage($message);
+        } else {
+            parent::setExpectedException($exception, $message, $code);
+        }
+    }
 }
