@@ -176,7 +176,7 @@ class MbstringTest extends TestCase
      */
     public function testEncodeNumericEntityWarnsOnInvalidIsHexType()
     {
-        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 4 to be boolean');
+        $this->setExpectedException('PHPUnit\Framework\Error\Warning', 'expects parameter 4 to be bool');
         mb_encode_numericentity('déjà', array(0x0, 0x10ffff, 0x0, 0x1fffff), 'UTF-8', new \stdClass());
     }
 
@@ -187,10 +187,11 @@ class MbstringTest extends TestCase
      */
     public function testStrCase()
     {
-        $this->assertSame('déjà σσς iiıi', mb_strtolower('DÉJÀ Σσς İIıi'));
+        $this->assertSame(\PHP_VERSION_ID >= 70300 ? 'i̇' : 'i', \mb_strtolower('İ'));
+        $this->assertSame('déjà σσς iiıi', p::mb_strtolower('DÉJÀ Σσς İIıi'));
         $this->assertSame('DÉJÀ ΣΣΣ İIII', mb_strtoupper('Déjà Σσς İIıi'));
         if (PCRE_VERSION >= '8.10') {
-            $this->assertSame('Déjà Σσσ Iı Ii İi', mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', MB_CASE_TITLE));
+            $this->assertSame('Déjà Σσσ Iı Ii İi', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', MB_CASE_TITLE));
         }
         if (PHP_VERSION_ID >= 70000) {
             // Native iconv() is buggy before PHP 7
@@ -198,6 +199,33 @@ class MbstringTest extends TestCase
         }
     }
 
+    /**
+     * @covers Symfony\Polyfill\Mbstring\Mbstring::mb_convert_case
+     */
+    public function testTitleCase()
+    {
+        for ($i = 1; $i < 127; ++$i) {
+            switch (chr($i)) {
+                case '!':
+                case '"':
+                case '#':
+                case '%':
+                case '&':
+                case '*':
+                case ',':
+                case '/':
+                case ';':
+                case '?':
+                case '@':
+                case '\\':
+                    if (\PHP_VERSION_ID < 70300) {
+                        continue 2;
+                    }
+            }
+            $this->assertSame(mb_convert_case('a'.chr($i).'b', MB_CASE_TITLE, 'UTF-8'), p::mb_convert_case('a'.chr($i).'b', MB_CASE_TITLE, 'UTF-8'), 'Title case for char 0x'.dechex($i));
+        }
+    }
+
     /**
      * @covers Symfony\Polyfill\Mbstring\Mbstring::mb_strlen
      */
